@@ -1,8 +1,13 @@
 /*
 	NO LICENSE
 */
-#include <ilbc/iLBC_encode.h>
-#include <ilbc/iLBC_decode.h>
+#ifdef ANDROID
+	#include <iLBC_encode.h>
+	#include <iLBC_decode.h>
+#else
+	#include <ilbc/iLBC_encode.h>
+	#include <ilbc/iLBC_decode.h>
+#endif /*ANDROID*/
 
 #include "mediastreamer2/msfilter.h"
 
@@ -18,9 +23,15 @@ typedef struct EncState{
 
 static void enc_init(MSFilter *f){
 	EncState *s=ms_new(EncState,1);
+#ifdef USE_20MS_FRAMES
 	s->nsamples=BLOCKL_20MS;
 	s->nbytes=NO_OF_BYTES_20MS;
 	s->ms_per_frame=20;
+#else
+	s->nsamples=BLOCKL_30MS;
+	s->nbytes=NO_OF_BYTES_30MS;
+	s->ms_per_frame=30;
+#endif
 	s->ptime=0;
 	s->ts=0;
 	ms_bufferizer_init(&s->bufferizer);
@@ -47,8 +58,10 @@ static int enc_add_fmtp(MSFilter *f, void *arg){
 	fmtp_get_value(fmtp, "mode", buf, sizeof(buf));
 	if (buf[0]=='\0'){
 		ms_warning("unsupported fmtp parameter (%s)!", fmtp);
+		return 0;
 	}
-	else if (strstr(buf,"20")!=NULL){
+	ms_message("iLBC encoder got mode=%s",buf);
+	if (strstr(buf,"20")!=NULL){
 		s->nsamples=BLOCKL_20MS;
 		s->nbytes=NO_OF_BYTES_20MS;
 		s->ms_per_frame=20;
